starcluster.threadpool.SimpleJob

Package starcluster :: Module threadpool :: Class SimpleJob |
[hide private]
[frames] | no frames]

# Class SimpleJob

source code

Instance Methods | [hide private]
__init__(self, method, args=`[``]`, jobid=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
run(self) The actual task for the job should be implemented here. | source code
Inherited from `workerpool.jobs.SimpleJob` (private): `_return` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, method, args=`[``]`, jobid=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### run(self) | source code
The actual task for the job should be implemented here. Overrides: workerpool.jobs.Job.run (inherited documentation)